==> patch-2.3.7.9.zip: app/views/report/syncDashboard.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><?=$data['title']?></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="ReportController">
    <span class="hide csrf_token"><?=$data['csrf_token']?></span>
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <?php if(!empty($_SESSION['OverReportResult'])){ ?>
            <?php if($_SESSION['OverReportResult'] == 404){ ?>
                <span class="resultError" style="display: none">Due to some technical issues could not download the file error code : 404</span>
            <?php }elseif($_SESSION['OverReportResult'] == 500){ ?>
                <span class="resultError" style="display: none">Due to some technical issues could not download the file error code : 500</span>
            <?php } ?>
            <?php $_SESSION['OverReportResult'] = ''; ?>
        <?php } ?>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak reportDashboard">
            <div class="row">
                <div class="col-lg-6">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title"> Overview </h3>
                        </div>
                        <div class="panel-body">
                            <p><a href="<?=Url::basePath('report/syncCLoudUsage')?>"> Sync Overview Summary</a></p>
                            <p><a href="<?=Url::basePath('report/download/syncOverviewReport')?>"> Sync User Activity History in Excel format</a></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script>
    $('.timePicker').timepicker({
        showMeridian: false,
        defaultTime: '9:45'
    });
</script>
<script src="<?=Url::templatePath()?>js/angular/controllers/ReportController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>

==> patch-2.5.3.11.zip: app/views/report/syncDashboard.php <==
<?php
use \Core\View;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Prashanth Kumar B - prashanth.kumar@parablu.com
* @version 2.0
* @date 7/10/15
* @time 11:55 AM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
                <li><h3><?=$data['title']?></h3></li>
                <li><?=$data['crumb1']?></li>
            </ol>
        </div>
        <div class="col-lg-6 hide">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="ReportController">
    <span class="hide csrf_token"><?=$data['csrf_token']?></span>
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php if(!isMobile()){ View::renderTemplate('partials/sideBar', $data); }?>
        </div>
        <?php if(!empty($_SESSION['OverReportResult'])){ ?>
            <?php if($_SESSION['OverReportResult'] == 404){ ?>
                <span class="resultError" style="display: none">Due to some technical issues could not download the file error code : 404</span>
            <?php }elseif($_SESSION['OverReportResult'] == 500){ ?>
                <span class="resultError" style="display: none">Due to some technical issues could not download the file error code : 500</span>
            <?php } ?>
            <?php $_SESSION['OverReportResult'] = ''; ?>
        <?php } ?>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak reportDashboard">
            <div class="row">
                <div class="col-lg-6">
                    <div class="panel panel-default">
                        <div class="panel-heading">
                            <h3 class="panel-title"> Overview </h3>
                        </div>
                        <div class="panel-body">
                            <p><a href="<?=Url::basePath('report/syncCLoudUsage')?>"> Sync Overview Summary</a></p>
                            <p><a href="<?=Url::basePath('report/download/syncOverviewReport')?>"> Sync User Activity History in Excel format</a></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script>
    $('.timePicker').timepicker({
        showMeridian: false,
        defaultTime: '9:45'
    });
</script>
<script src="<?=Url::templatePath()?>js/angular/controllers/ReportController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
